from select import select
from requests import request
from bs4 import BeautifulSoup
import re,json


class Manhwa18Parser:
    def __init__(self):
        self.HOST_URL = 'https://manhwa18.cc/'
        self.SEARCH_URL = self.HOST_URL+'search?q='

    def search(self,key):
        res = request('GET',self.SEARCH_URL+key).content
        soup = BeautifulSoup(res,'html.parser')
        return list(map(
            lambda it: {"cover":it['src'],"name":it['alt']},
            soup.select('body > div.manga-content.wleft > div > div > div > div.manga-lists > div > div > div.thumb > a > img')
        ))

    def loadChapters(self,query):
        page = request('GET',self.HOST_URL+'webtoon/'+query).content
        soup = BeautifulSoup(page,'html.parser')
        return list(map(
            lambda it:  {"chapterLink":it['href'],"chapter":it.get_text()},
            soup.select("#chapterlist > ul > li > a")
        ))

    def loadImages(self,chLink):
        page = request('GET',chLink).content
        soup = BeautifulSoup(page,'html.parser')
        return list(map(
            lambda it:  it['src'],
            soup.select("div.read-content.wleft.tcenter > img")
        ))

    def proxyImages(self,imgLink):
        headers = { "referer":"https://manhwa18.cc/",
                    "authority":"img01.iwa-18cc.xyz",
                    "user-agent":"Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"
                }
        return request('GET',imgLink,headers=headers).content



m = Manhwa18Parser()
print(m.search("secr"))


from base64 import b64decode, b64encode
from requests import request
import json


class HanimeParser:
    def __init__(self,hanime="",ep = 1) -> None:
        self.hanime,self.ep = hanime,ep

    def search(self,key):
        url = "https://search.htv-services.com/"
        payload = {"search_text":key,"tags":[],"tags_mode":"AND","brands":[],"blacklist":[],"order_by":"created_at_unix","ordering":"desc","page":0}
        headers = {
        'Accept': 'application/json, text/plain, */*',
        'User-Agent': 'Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.5060.66 Mobile Safari/537.36',
        'Content-Type': 'application/json;charset=UTF-8',
        'Sec-GPC': '1',
        'Sec-Fetch-Site': 'cross-site',
        'Sec-Fetch-Mode': 'cors',
        'Sec-Fetch-Dest': 'empty',
        'host': 'search.htv-services.com'
        }
        response = request("POST", url, headers=headers, data=json.dumps(payload))
        return response.text

    def getHanimeEp(self):
        url = 'https://hanime.tv/api/v8/video?id={}-{}'.format(self.hanime,self.ep)
        print(url)
        res = request('GET',url).text
        res = json.loads(res)
        # m3u8 = res['videos_manifest']['servers'][0]['streams'][1]['url']
        return res



from base64 import b64decode, b64encode
from cgi import print_arguments
from requests import request
import requests
from bs4 import BeautifulSoup
import re
import json
from Yowaimo.Parsers.constants import *
from Yowaimo.myCrypto.KdramaCrypto import KdramaCrypto


class KdramaParaser(KdramaCrypto):
    def __init__(self) -> None:
        super().__init__(KDRAMA_KEY, KDRAMA_IV)
        self.baseUrl, self.baseAjaxUrl, self.iframeReqHeaders, self.m3u8ReqHeaders = KDRAMA_BASE_URL, KDRAMA_AJAX_URL, KDRAMA_IFRAME_HEADERS, KDRAMA_M3U8_HEADERS

    # def search(self, drama):
    #     page = requests.get(f'{KDRAMA_BASE_HOST}//search.html?keyword={drama}')
    #     soup = BeautifulSoup(page.content, 'html.parser')
    #     img, name, meta = soup.find_all('div', {'class': 'picture'}), soup.find_all(
    #         'div', {'class': 'name'}), soup.find_all('div', {'class': 'meta'})
    #     searchjson = []
    #     for i in range(len(img)):
    #         searchjson.append({
    #             "drama": " ".join(name[i].getText().strip().split()[:-2]),
    #             "cover": img[i].img['src'], "meta": meta[i].getText().strip(),
    #             "episode": " ".join(name[i].getText().strip().split()[-2:])})
    #     return searchjson

    def search2(self, drama):
        page = requests.get(f'{KDRAMA_BASE_HOST}//search.html?keyword={drama}')
        soup = BeautifulSoup(page.content, 'html.parser')
        return list(
            map(lambda it: {"drama": it['alt'], "cover": it['src']},
                soup.select('#main_bg > div:nth-child(5) > div > div.vc_row.wpb_row.vc_row-fluid.vc_custom_1404913114846 > div.vc_col-sm-12.wpb_column.column_container > div > div > ul > li > a > div.img > div.picture > img')))

    # def getdramainfo(self, drama):
    #     page = requests.get(f'{KDRAMA_BASE_HOST}//videos/{drama}-episode-1')
    #     soup = BeautifulSoup(page.content, 'html.parser')
    #     dramainfo = []
    #     img, name, meta = soup.find_all('div', {'class': 'picture'}), soup.find_all(
    #         'div', {'class': 'name'}), soup.find_all('div', {'class': 'meta'})
    #     info = soup.find('div', {'class': 'content-more-js'})
    #     total_episodes = int(name[0].getText().strip().split()[-1])
    #     episode_thumbnails = []
    #     latest_episodes = []
    #     for i in range(total_episodes):
    #         episode_thumbnails.append(img[i].img['src'])
    #     for i in range(total_episodes, len(name)):
    #         latest_episodes.append({
    #             "drama": " ".join(name[i].getText().strip().split()[:-2]),
    #             "cover": img[i].img['src'], "meta": meta[i].getText().strip(),
    #             "episode": " ".join(name[i].getText().strip().split()[-2:])})
    #     dramainfo.append({
    #         "summary": info.getText()[1:],
    #         "total_episodes": total_episodes,
    #         "episode_thumbnails": episode_thumbnails})
    #     return dramainfo

    def getdramainfo2(self, drama):
        page = requests.get(f'{KDRAMA_BASE_HOST}//videos/{drama}-episode-1')
        soup = BeautifulSoup(page.content, 'html.parser')
        dramainfo = []
        total_episodes = len(soup.select(
            '#main_bg > div:nth-child(5) > div > div.video-info-left > ul > li'))
        info = soup.find('div', {'class': 'content-more-js'})
        dramainfo.append({
            "summary": info.getText()[1:],
            "total_episodes": total_episodes})
        return dramainfo

    # def homepage(self):
    #     page = requests.get(KDRAMA_BASE_HOST)
    #     soup = BeautifulSoup(page.content, 'html.parser')
    #     img, name = soup.find_all('div', {'class': 'picture'}), soup.find_all(
    #         'div', {'class': 'name'})
    #     homejson = []
    #     for i in range(len(img)):
    #         homejson.append({
    #             "drama": " ".join(name[i].getText().strip().split()[:-2]),
    #             "cover": img[i].img['src'],
    #             "episode": " ".join(name[i].getText().strip().split()[-2:])})
    #     return homejson

    def homepage2(self):
        page = requests.get(KDRAMA_BASE_HOST)
        soup = BeautifulSoup(page.content, 'html.parser')
        return list(
            map(lambda it: {'drama': it['alt'], 'cover': it['src']},
                soup.select('#main_bg > div:nth-child(5) > div > div.vc_row.wpb_row.vc_row-fluid.vc_custom_1404913114846 > div.vc_col-sm-12.wpb_column.column_container > div > div > ul > li > a > div.img > div.picture > img')))

    def getIframeUrl(self, url):
        data = request("GET", url).text
        surl = re.findall(r'//dembed.*\" all', data)
        return surl[0][:-5]

    def getMsgFromIframe(self, url):
        response = request("GET", url, headers=self.iframeReqHeaders, data={})
        data = response.text
        msg = re.findall(r'data-value.*><', data)[0]
        msg = msg[11:-2]
        return msg

    def makeM3u8ReqUrl(self, msg):
        print(msg)
        new_url = self._decrypt(msg)
        print(new_url)
        print(type(new_url))
        id_msg = new_url[:8].decode("utf-8")
        new_id = self._encrypt(id_msg)
        return self.baseAjaxUrl+"?id="+new_id+new_url[8:].decode("utf-8")+"&alias="+id_msg

    def getM3u8(self, url):
        response = request("GET", url, headers=self.m3u8ReqHeaders, data={})
        data = json.loads(response.text)['data']
        return self._decrypt(data).decode("utf-8")

    def getVidLink(self, drama, episode):
        try:
            print(drama,episode)
            url = self.getIframeUrl(KDRAMA_BASE_URL+drama+"-episode-"+episode)
            msg = self.getMsgFromIframe("https:"+url)
            final_url = self.makeM3u8ReqUrl(msg)
            res = self.getM3u8(final_url)
            out = json.loads(res)
            return out['source'][0]['file']
        except:
            return json.dumps({"eror": "error occured while scrapping"})



from base64 import b64decode, b64encode
from Crypto.Cipher import AES
from Crypto.Util.Padding import unpad
from Crypto.Random import get_random_bytes
from Crypto.Util.Padding import pad

class BaseCrypto:
    def __init__(self,key,iv) -> None:
        self.key,self.iv = key,iv

    def _encrypt(self,msg):
        try:        
            cipher = AES.new(self.key.encode("utf8"), AES.MODE_CBC, self.iv.encode("utf8"))
            ct_bytes = cipher.encrypt(pad(msg.encode("utf8"), AES.block_size))
            ct = b64encode(ct_bytes).decode("utf8")
            return ct
        except ValueError as e:
            return e

    def _decrypt(self,msg):
        try:
            iv = self.iv.encode("utf8")
            ct = b64decode(msg)
            cipher = AES.new(self.key.encode("utf8"), AES.MODE_CBC, iv)
            pt = unpad(cipher.decrypt(ct), AES.block_size)
            return pt
        except (ValueError, KeyError):
            return ValueError


from Yowaimo.myCrypto.BaseCrypto import *

class GogoCrypto(BaseCrypto):
    def __init__(self,key,iv) -> None:
        super().__init__(key,iv)

    
    def _decryptGogom3u8(self,msg,key):
        try:
            iv = self.iv.encode("utf8")
            ct = b64decode(msg)
            cipher = AES.new(key.encode("utf8"), AES.MODE_CBC, iv)
            pt = unpad(cipher.decrypt(ct), AES.block_size)
            return pt
        except (ValueError, KeyError):
            return ValueError




BASE_URL = "https://gogoanime.gg/"

AJAX_URL = "https://goload.pro/encrypt-ajax.php"

KEY = "37911490979715163134003223491201"

KEY2 = "54674138327930866480207815084989"

IV = "3134003223491201"

GOGO_IFRAME_HEADERS = {
    'Upgrade-Insecure-Requests': '1',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.61 Safari/537.36',
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
    'Sec-GPC': '1',
    'host': 'goload.pro'
}

GOGO_M3U8_HEADERS = {
    'Accept': 'application/json, text/javascript, */*; q=0.01',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.61 Safari/537.36',
    'X-Requested-With': 'XMLHttpRequest',
    'Sec-GPC': '1',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Dest': 'empty'
}

KDRAMA_BASE_HOST = 'https://dembed1.com/'
KDRAMA_BASE_URL = 'https://dembed1.com/videos/'
KDRAMA_AJAX_URL = 'https://dembed1.com/encrypt-ajax.php'
KDRAMA_KEY = '93422192433952489752342908585752'
KDRAMA_IV = '9262859232435825'


KDRAMA_IFRAME_HEADERS = {
    'Upgrade-Insecure-Requests': '1',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.61 Safari/537.36',
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
    'Sec-GPC': '1',
    'host': 'dembed2.com'
}
KDRAMA_M3U8_HEADERS = {
    'Accept': 'application/json, text/javascript, */*; q=0.01',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.61 Safari/537.36',
    'X-Requested-With': 'XMLHttpRequest',
    'Sec-GPC': '1',
    'Sec-Fetch-Site': 'same-origin',
    'Sec-Fetch-Mode': 'cors',
    'Sec-Fetch-Dest': 'empty'
}



from base64 import b64decode, b64encode
from select import select
from requests import request
import requests
from bs4 import BeautifulSoup
import re,json
from Yowaimo.Parsers.constants import *
from Yowaimo.myCrypto.GogoCrypto import GogoCrypto

class GogoParser(GogoCrypto):
    def __init__(self) -> None:
        super().__init__(KEY, IV)
        self.baseUrl, self.baseAjaxUrl, self.iframeReqHeaders, self.m3u8ReqHeaders = BASE_URL, AJAX_URL, GOGO_IFRAME_HEADERS, GOGO_M3U8_HEADERS

    def getIframeUrl(self, url):
        data = request("GET", url).text
        surl = re.findall(r'goload.* s', data)
        return surl[0][:-3]

    def getMsgFromIframe(self, url):
        response = request("GET", url, headers=self.iframeReqHeaders, data={})
        data = response.text
        msg = re.findall(r'data-value.*><', data)[0]
        msg = msg[11:-2]
        return msg

    def makeM3u8ReqUrl(self, msg):
        print(msg)
        new_url = self._decrypt(msg)
        print(new_url)
        print(type(new_url))
        id_msg = new_url[:8].decode("utf-8")
        new_id = self._encrypt(id_msg)
        return self.baseAjaxUrl+"?id="+new_id+new_url[8:].decode("utf-8")+"&alias="+id_msg

    def getM3u8(self, url):
        response = request("GET", url, headers=self.m3u8ReqHeaders, data={})
        data = json.loads(response.text)['data']
        return self._decryptGogom3u8(data, KEY2).decode("utf-8")

    def getVidLink(self, anime, episode):
        try:
            url = self.getIframeUrl(BASE_URL+anime+"-episode-"+episode)
            if 'm3u8' in url:
                return url
            msg = self.getMsgFromIframe("https://"+url)
            final_url = self.makeM3u8ReqUrl(msg)
            res = self.getM3u8(final_url)
            out = json.loads(res)
            return out['source'][0]['file']
        except:
            return json.dumps({"eror": "error occured while scrapping"})

    # def search(self, anime):
    #     page = requests.get(
    #         f'{BASE_URL}//search.html?keyword={anime}')
    #     soup = BeautifulSoup(page.content, 'html.parser')
    #     img, name, rel = soup.find_all('div', {'class': 'img'}), soup.find_all(
    #         'p', {'class': 'name'}), soup.find_all('p', {'class': 'released'})
    #     searchjson = []
    #     for i in range(len(img)):
    #         searchjson.append({"anime": name[i].getText(), "link": img[i].a['href'], "thumbnail": img[i].a.img['src'],
    #                            "release": rel[i].getText().replace(' ', '').replace('\n', '')})

    #     return searchjson

    def search2(self,anime):
        page = requests.get(f'{BASE_URL}//search.html?keyword={anime}')
        soup = BeautifulSoup(page.content, 'html.parser')
        return list(map(
            lambda it: {"anime":it['alt'],"thumbnail":it['src']},
            soup.select("#wrapper_bg > section > section.content_left > div > div.last_episodes > ul > li > div > a > img")
        ))

    def getanimeinfo(self, animeurlname):
        filteruri = animeurlname.replace(' ', '')
        page = requests.get(
            f'{BASE_URL}//category/{filteruri}')
        animeinfosoup = BeautifulSoup(page.content, 'html.parser')
        animeinfo = []
        reps = []
        # n = animeinfosoup.find('div', {'class': 'anime_info_episodes'}).h2.text
        for ep in animeinfosoup.find_all('a', {'href': '#'}):
            reps.append(ep.text)
        epcountreps = 0
        try:
            ind = reps[-1].index("-")
            epcountreps = reps[-1][ind+1:].replace(" ", "")
        except:
            epcountreps = reps[-1]
        for i in animeinfosoup.find_all('p', {'class': 'type'}):
            animeinfo.append(i.text.replace("\n", ""))
        tjson = []
        tjson.append({"type": animeinfo[0][5:], "plot": animeinfo[1][13:], "genre": animeinfo[2][6:].replace(
            '  ', ''), "released": animeinfo[3], "episodes_released": int(epcountreps)})
        return tjson

    def getifr(self, animeep, anime):
        page = requests.get(
            f"{BASE_URL}/{anime}-episode-{animeep}")
        epsoup = BeautifulSoup(page.content, 'html.parser')
        link = epsoup.find_all('li', {'class': 'streamsb'})[0].a['data-video']
        return link

    # def homepage(self):
    #     page = requests.get(
    #         f'{BASE_URL}')
    #     soup = BeautifulSoup(page.content, 'html.parser')
    #     img, name, rel = soup.find_all('div', {'class': 'img'}), soup.find_all(
    #         'p', {'class': 'name'}), soup.find_all('p', {'class': 'episode'})
    #     searchjson = []
    #     for i in range(len(img)):
    #         searchjson.append({"anime": name[i].getText(), "cover": img[i].a.img['src'],
    #                            "latestep": rel[i].getText().replace(' ', '').replace('\n', '')})

    #     return searchjson

    def homepage2(self):
        page = request('GET',BASE_URL).content
        soup = BeautifulSoup(page,'html.parser')
        return list(map(
            lambda it:  {"anime":it['alt'],"cover":it['src']},
            soup.select("#load_recent_release > div.last_episodes.loaddub > ul > li > div > a > img")
        ))

    def animeInfo2(self,anime):
        page = request('GET',BASE_URL+"category/"+anime).content
        soup = BeautifulSoup(page, 'html.parser')
        print(soup.select("#episode_related > li:nth-child(1) > a > div.name"))
        return list(map(
            lambda it:  {"type":it.select("p:nth-child(4) > a")[0]['title'],
                        "plot":it.select("p:nth-child(5)")[0].get_text(),
                        "genre":it.select("p:nth-child(6)")[0].get_text(),
                        "released":it.select("p:nth-child(6)")[0].get_text(),
                        "episodes_released":int(soup.select('#episode_page > li > a.active')[0]['ep_end'])},
            soup.select("#wrapper_bg > section > section.content_left > div.main_body > div:nth-child(2) > div.anime_info_body_bg")
        ))



# class GogoParser(GogoCrypto):
#     def __init__(self) -> None:
#         super().__init__(KEY,IV)
#         self.baseUrl,self.baseAjaxUrl,self.iframeReqHeaders,self.m3u8ReqHeaders = BASE_URL,AJAX_URL,GOGO_IFRAME_HEADERS,GOGO_M3U8_HEADERS
        
#     def getIframeUrl(self,url):
#         data = request("GET", url).text
#         surl = re.findall(r'goload.* s', data) 
#         return surl[0][:-3]
    
#     def getMsgFromIframe(self,url):
#         response = request("GET", url, headers=self.iframeReqHeaders, data={})
#         data = response.text
#         msg = re.findall(r'data-value.*><',data)[0]
#         msg = msg[11:-2]
#         return msg

#     def makeM3u8ReqUrl(self,msg):
#         print(msg)
#         new_url = self._decrypt(msg)
#         print(new_url)
#         print(type(new_url))
#         id_msg = new_url[:8].decode("utf-8")
#         new_id = self._encrypt(id_msg)
#         return self.baseAjaxUrl+"?id="+new_id+new_url[8:].decode("utf-8")+"&alias="+id_msg

#     def getM3u8(self,url):
#         response = request("GET", url, headers=self.m3u8ReqHeaders, data={})
#         data = json.loads(response.text)['data']
#         return self._decryptGogom3u8(data,KEY2).decode("utf-8")




# class VidStreamingParser(KdramaCrypto,GogoCrypto):
#     def __init__(self,baseUrl,baseAjaxUrl,iframeReqHeaders,m3u8ReqHeaders) -> None:
#         KdramaCrypto.__init__(self,KDRAMA_KEY,KDRAMA_IV)
#         super().__init__(KEY,IV)
#         self.baseUrl,self.baseAjaxUrl,self.iframeReqHeaders,self.m3u8ReqHeaders = baseUrl,baseAjaxUrl,iframeReqHeaders,m3u8ReqHeaders
    
#     def getMsgFromIframe(self,url):
#         response = request("GET", url, headers=self.iframeReqHeaders, data={})
#         data = response.text
#         msg = re.findall(r'data-value.*><',data)[0]
#         msg = msg[11:-2]
#         return msg

#     def makeM3u8ReqUrl(self,msg):
#         print(msg)
#         new_url = self._decrypt(msg)
#         print(new_url)
#         print(type(new_url))
#         id_msg = new_url[:8].decode("utf-8")
#         new_id = self._encrypt(id_msg)
#         return self.baseAjaxUrl+"?id="+new_id+new_url[8:].decode("utf-8")+"&alias="+id_msg